# BaseUpstreams

Response object for a list issuer upstreams query
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**upstreams** | [**list[BaseUpstream]**](BaseUpstream.md) | List of upstreams | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


